package com.yundong.third.ht.api.database.impl;


import com.yundong.base.result.Result;
import com.yundong.base.service.oss.OssService;
import com.yundong.gateway.register.annotation.YdcGateway;
import com.yundong.third.ht.api.database.ContractCounterExportRequest;
import com.yundong.third.ht.api.database.dto.request.ContractCounterSignExportWordRequest;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.apache.dubbo.config.annotation.Service;
import org.apache.poi.hwpf.HWPFDocument;
import org.apache.poi.hwpf.usermodel.Range;
import org.springframework.beans.factory.annotation.Autowired;

import javax.validation.Valid;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.util.*;

/**
 * @Author LTC
 * @Date 2023-12-21 15:36
 */
@Slf4j
@org.springframework.stereotype.Service
@Service(version = "${dubbo.provider.version}", group = "${dubbo.provider.group}")
public class ContractCounterExportRequestImpl implements ContractCounterExportRequest {
    @Autowired
    private OssService ossService;

    @YdcGateway(name = "contractCounter-export", url = "biz/third/ht/database/contractExport.json")
    @Override
    public Result<List<String>> ContractCounterExport(@Valid ContractCounterSignExportWordRequest request) {
        Result<List<String>> result = new Result<>();
        List<String> fileUrls = new ArrayList<>();
        for (int i = 0; i < request.getData().size(); i++) {
            HashMap<String, Object> map = new HashMap<>();
            map.put("contractName", StringUtils.isNotBlank(request.getData().get(i).getContractName())? request.getData().get(i).getContractName():"\u00A0");
            map.put("partyAName", StringUtils.isNotBlank(request.getData().get(i).getPartyAName())?request.getData().get(i).getPartyAName():"\u00A0");
            map.put("contractAmount", StringUtils.isNotBlank(request.getData().get(i).getContractAmount())?request.getData().get(i).getContractAmount():"\u00A0");
            map.put("undertakingDepartment", StringUtils.isNotBlank(request.getData().get(i).getUndertakingDepartment())?request.getData().get(i).getUndertakingDepartment():"\u00A0");
            map.put("undertakingUser", StringUtils.isNotBlank(request.getData().get(i).getUndertakingUser())?request.getData().get(i).getUndertakingUser():"\u00A0");
            map.put("signature", StringUtils.isNotBlank(request.getData().get(i).getSignature())?request.getData().get(i).getSignature():"\u00A0");
            map.put("date", StringUtils.isNotBlank(request.getData().get(i).getDate())?request.getData().get(i).getDate():"\u00A0");
            map.put("leader", StringUtils.isNotBlank(request.getData().get(i).getLeader())?request.getData().get(i).getLeader():"\u00A0");
            map.put("depts", StringUtils.isNotBlank(request.getData().get(i).getDepts())?request.getData().get(i).getDepts():"\u00A0");
            map.put("deptLeader", StringUtils.isNotBlank(request.getData().get(i).getDeptLeader())?request.getData().get(i).getDeptLeader():"\u00A0");
            map.put("successStatus", StringUtils.isNotBlank(request.getData().get(i).getSuccessStatus())?request.getData().get(i).getSuccessStatus():"\u00A0");
            String fileName = "合同会签单";
            String fileUrl = "";
//        String relativePath = "\\yundong-third-ht\\src\\main\\resources\\word\\con_export.doc"; // 相对路径
//        String currentDir = System.getProperty("user.dir");
//        String filePath = currentDir + File.separator + relativePath; // 构建完整的文件路径
            try {
                File catchFile = File.createTempFile(UUID.randomUUID().toString(), ".doc");
                try (
                        InputStream resource = ContractCounterExportRequestImpl.class.getClassLoader().getResourceAsStream("word/con_export.doc");
                        FileOutputStream fileOutputStream = new FileOutputStream(catchFile);
                        FileInputStream fileInputStream = new FileInputStream(catchFile);
//                    FileOutputStream out = new FileOutputStream("output.doc");
                ) {
                    HWPFDocument doc = new HWPFDocument(resource);
                    Range range = doc.getRange();
                    for (Map.Entry<String, Object> entry : map.entrySet()) {
                        range.replaceText(entry.getKey(), String.valueOf(entry.getValue()));
                    }
//                response.setHeader("Content-disposition","attachment;filename=\""+new String(fileName.getBytes("UTF-8"),"ISO8859_1")+"\"");
//                response.setContentType("application/download;charset=UTF-8");
//                ServletOutputStream out = response.getOutputStream();
                    doc.write(fileOutputStream);
                    fileUrl = ossService.uploadOssObject(request.getTenantId(), System.currentTimeMillis() + "/" + fileName + ".doc", fileInputStream);
                    fileUrls.add(fileUrl);
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
        }

        result.setData(fileUrls);
        result.setCode(200);
        result.setMessage("成功");
        return result;
    }
}
